@@ -12,10 +12,10 @@ struct User{
 
 fn main_async() -> Result<()>{
     let db = DataBase::new("localhost", 3306, "rust", "root", "");
-    let row = db.get_row("users".to_string(), "id = 1".to_string(), "".to_string(), "".to_string());
-    if row.is_ok(){
-        let user:User = utils::map_to_struct(row.unwrap())?;
-        println!("USER {:?}", user);
+    let rows = db.get_list("users".to_string(), "".to_string(), "10".to_string(), "id ASC".to_string(), "id, name".to_string());
+    if rows.is_ok(){
+        let result:Vec<User> = utils::map_vec_to_struct_vec(rows.unwrap())?;
+        println!("USER {:?}", result);
     }
     
     Ok(())
